using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using SharpCharts.Base.Data;
using System.Windows.Media;

namespace SharpCharts.Base.MarketWatch
{
	
	
    public class Arbitrage : ScannerBase
    {
    	double primary, seconday;
    	
        public Arbitrage()
        {
            this.ExpiryDate = DateTime.Today;
            this.MarketDataType = MarketDataType.Last;
            
            base.CellConditionItems = new CellConditionItemBase[2];
            base.CellConditionItems[0] = new CellConditionItem<double>()
            	{
            		Condition = Common.Condition.GreaterThan,
            		CellValue = 1.0d,
            		Background = Brushes.PaleGreen
            	};
            
            base.CellConditionItems[1] = new CellConditionItem<double>()
            	{
            		Condition = Common.Condition.LessThan,
            		CellValue = -1.0d,
            		Background = Brushes.LightPink
            	};
        }

        protected override void OnStateChange()
        {
            switch (base.State)
            {
                case SharpCharts.Base.SharpScript.State.Finalize:
                    break;
                case SharpCharts.Base.SharpScript.State.Initialize:

                    base.IsLevel1Subscribed = true;
                    if (base.Instrument == null)
                    	return;
                    	
                    string instrument = string.Format("{0} {1:MM yyyy} NSE", 
                    	base.Instrument.InstrumentDefination.Name,
                    	this.ExpiryDate).ToUpper();
                    
                    AddInstrument(instrument);
                    
                    break;
            }
        }
        
		protected override void OnLevel1(int idx, RealTimeDataEventArgs e)
		{
			if (idx == 0)
			{
				if (e.MarketDataType != MarketDataType.Last)
					return;
					
				this.primary = e.Price;
				Calculate();
			}
			else if (idx == 1)
			{
				if (e.MarketDataType != this.MarketDataType)
					return;
				
				this.seconday = e.Price;
				Calculate();
			}
		}
		
		private void Calculate()
		{
			if (this.primary > 0.0d && this.seconday > 0.0d)
			{
				this.DisplayValue = Math.Round((this.seconday - this.primary) / this.primary * 100, 3);
			}
		}
		
		
		public MarketDataType[] MarketDataTypes
		{
			get { return new MarketDataType[] { MarketDataType.Last, MarketDataType.Bid, MarketDataType.Ask }; }
		}
		
		public MarketDataType MarketDataType { get; set; }
		
		public DateTime ExpiryDate { get; set; }
		
		public override string HeaderString 
		{
			get { return string.Format("ARB {0:MMM yyyy}", this.ExpiryDate); }
		}
		
		public override string DisplayName 
		{
			get { return string.Format("ARB {0:MMM yyyy}", this.ExpiryDate); }
		}
    }
}